@@ -1,5 +1,6 @@
 from unit.models import *
 
+
 class CustomerTokenDTO(object):
     def __init__(self, token: str, expires_in: int):
         self.type = "customerBearerToken"
@@ -9,6 +10,7 @@ class CustomerTokenDTO(object):
     def from_json_api(_id, _type, attributes, relationships):
         return CustomerTokenDTO(attributes["token"], attributes["expiresIn"])
 
+
 class CustomerVerificationTokenDTO(object):
     def __init__(self, verification_token: str):
         self.type = "customerTokenVerification"
@@ -22,13 +24,13 @@ class CustomerVerificationTokenDTO(object):
 class CreateCustomerToken(UnitRequest):
     def __init__(self, customer_id: str, scope: str, verification_token: Optional[str] = None,
                  verification_code: Optional[str] = None, expires_in: Optional[int] = None,
-                 jwt_subject: Optional[str] = None):
+                 jwt_token: Optional[str] = None):
         self.customer_id = customer_id
         self.scope = scope
         self.verification_token = verification_token
         self.verification_code = verification_code
         self.expires_in = expires_in
-        self.jwt_subject = jwt_subject
+        self.jwt_token = jwt_token
 
     def to_json_api(self) -> Dict:
         payload = {
@@ -49,8 +51,8 @@ class CreateCustomerToken(UnitRequest):
         if self.verification_code:
             payload["data"]["attributes"]["verificationCode"] = self.verification_code
 
-        if self.jwt_subject:
-            payload["data"]["attributes"]["jwtSubject"] = self.jwt_subject
+        if self.jwt_token:
+            payload["data"]["attributes"]["jwtToken"] = self.jwt_token
 
         return payload
 
